from datetime import timedelta
from feast import Entity, Field, FeatureView, FileSource
from feast.types import Float32, String

# Define the source file for customer purchases data
customer_purchases_source = FileSource(
    path="data/customer_purchases_29102024.parquet",
    timestamp_field="event_timestamp"
)

# Define the customer entity
customer = Entity(name="customer_id", join_keys=["customer_id"])

# Define the feature view for customer purchases
customer_purchases_view = FeatureView(
    name="customer_purchases",
    entities=[customer],
    ttl=timedelta(days=365),
    schema=[
        Field(name="purchase_amount", dtype=Float32),
        Field(name="purchase_category", dtype=String),
    ],
    online=True,
    source=customer_purchases_source
)
